@@ -16,6 +16,7 @@ from datatailr.blob import Blob
 from datatailr.build import Image
 from datatailr.utils import Environment, is_dt_installed
 from datatailr.version import __version__
+from datatailr.scheduler import App, Service, ExcelAddin
 
 system = dt__System()
 if isinstance(system, mock_cli_tool):
@@ -33,4 +34,7 @@ __all__ = [
     "__version__",
     "__provider__",
     "is_dt_installed",
+    "App",
+    "Service",
+    "ExcelAddin",
 ]
