@@ -10,12 +10,14 @@
 
 from __future__ import annotations
 
+import os
 import tempfile
 
 from datatailr.wrapper import dt__Blob
 
 # Datatailr Blob API Client
 __client__ = dt__Blob()
+__user__ = os.getenv("USER", "root")
 
 
 class Blob:
@@ -81,8 +83,13 @@ class Blob:
         """
         # Since direct reading and writting of blobs is not implemented yet, we are using a temporary file.
         # This is a workaround to allow reading the blob content directly from the blob storage.
-
-        with tempfile.NamedTemporaryFile(delete=True) as temp_file:
+        temp_dir = f"/home/{__user__}/tmp"
+        if not os.path.exists(temp_dir):
+            temp_dir = "/tmp"
+        else:
+            temp_dir += "/.dt"
+            os.makedirs(temp_dir, exist_ok=True)
+        with tempfile.NamedTemporaryFile(dir=temp_dir, delete=True) as temp_file:
             self.get_file(name, temp_file.name)
             with open(temp_file.name, "r") as f:
                 return f.read()
