@@ -28,6 +28,7 @@ from typing import Any, Dict, Optional
 
 from datatailr import is_dt_installed, Blob
 from datatailr.errors import DatatailrError
+from datatailr.wrapper import dt__Tag
 
 
 __BLOB_STORAGE__ = Blob()
@@ -48,11 +49,12 @@ class ArgumentsCache:
 
         :param use_persistent_cache: If True, use the persistent cache backend. Otherwise, use in-memory cache.
         """
+        self.__bucket_name__ = dt__Tag().get("blob_storage_prefix") + "batch"
         self.use_persistent_cache = use_persistent_cache
         if not self.use_persistent_cache:
             # Create a temp folder, for local caching
-            os.makedirs("/tmp/datatailr/batch/arguments", exist_ok=True)
-            os.makedirs("/tmp/datatailr/batch/results", exist_ok=True)
+            os.makedirs(f"/tmp/{self.__bucket_name__}/arguments", exist_ok=True)
+            os.makedirs(f"/tmp/{self.__bucket_name__}/results", exist_ok=True)
 
     def add_arguments(self, batch_id: str, arguments: Dict[str, Any]):
         """
@@ -62,7 +64,7 @@ class ArgumentsCache:
         :param job_name: Name of the job.
         :param arguments: Dictionary of arguments to store.
         """
-        path = f"/tmp/datatailr/batch/arguments/{batch_id}.pkl"
+        path = f"/tmp/{self.__bucket_name__}/arguments/{batch_id}.pkl"
         if self.use_persistent_cache:
             self._add_to_persistent_cache(path, arguments)
         else:
@@ -79,7 +81,7 @@ class ArgumentsCache:
         :param job_name: Name of the job.
         :return: Dictionary of arguments.
         """
-        path = f"/tmp/datatailr/batch/arguments/{batch_id}.pkl"
+        path = f"/tmp/{self.__bucket_name__}/arguments/{batch_id}.pkl"
         if self.use_persistent_cache and isinstance(job, str):
             try:
                 arg_keys = self._get_from_persistent_cache(path)
@@ -115,7 +117,7 @@ class ArgumentsCache:
         :param job: Name of the job.
         :param result: Result of the batch job.
         """
-        path = f"/tmp/datatailr/batch/results/{batch_run_id}/{job}.pkl"
+        path = f"/tmp/{self.__bucket_name__}/results/{batch_run_id}/{job}.pkl"
         if self.use_persistent_cache and isinstance(job, str):
             self._add_to_persistent_cache(path, result)
         else:
@@ -131,7 +133,7 @@ class ArgumentsCache:
         :param job: Name of the job.
         :return: Result of the batch job.
         """
-        path = f"/tmp/datatailr/batch/results/{batch_run_id}/{job}.pkl"
+        path = f"/tmp/{self.__bucket_name__}/results/{batch_run_id}/{job}.pkl"
         if self.use_persistent_cache and isinstance(job, str):
             return self._get_from_persistent_cache(path)
         else:
