@@ -142,7 +142,7 @@ class Job:
         environment: Optional[Environment] = Environment.DEV,
         image: Optional[Image] = None,
         run_as: Optional[Union[str, User]] = None,
-        resources: Resources = Resources(memory="128m", cpu=0.25),
+        resources: Resources = Resources(),
         acl: Optional[ACL] = None,
         python_version: str = "3.12",
         python_requirements: str = "",
@@ -293,6 +293,7 @@ class Job:
         Returns a tuple of (branch: str, commit_hash: str).
         """
         path_to_repo = self.image.path_to_repo or "."
+        branch_name, local_commit, return_code = "unknown", "unknown", None
         try:
             local_commit = run_shell_command(
                 f"cd {path_to_repo} && git rev-parse HEAD"
@@ -300,6 +301,13 @@ class Job:
             branch_name = run_shell_command(
                 f"cd {path_to_repo} && git rev-parse --abbrev-ref HEAD"
             )[0]
+
+            if (
+                os.getenv("DATATAILR_ALLOW_UNSAFE_SCHEDULING", "false").lower()
+                == "true"
+            ):
+                return branch_name, local_commit
+
             return_code = run_shell_command(
                 f"cd {path_to_repo} && git diff --exit-code"
             )
@@ -308,15 +316,11 @@ class Job:
                 logger.warning(
                     "Git is not installed or not found in PATH. Repository validation is not possible."
                 )
-                branch_name, local_commit, return_code = "unknown", "unknown", None
             else:
                 raise RepoValidationError(
                     f"Error accessing git repository at {path_to_repo}: {e}"
                 ) from e
 
-        if os.getenv("DATATAILR_ALLOW_UNSAFE_SCHEDULING", "false").lower() == "true":
-            return branch_name, local_commit
-
         is_committed = return_code is not None and return_code[1] == 0
 
         if not is_committed:
