@@ -35,9 +35,17 @@ from datatailr.scheduler.schedule import Schedule
 from datatailr.utils import is_dt_installed, dict_to_env_vars
 
 __DAG_CONTEXT__: contextvars.ContextVar = contextvars.ContextVar("dag_context")
-__ARGUMENTS_CACHE__ = ArgumentsCache()
 logger = DatatailrLogger(os.path.abspath(__file__)).get_logger()
 
+__ARGUMENTS_CACHE__ = None
+
+
+def get_arguments_cache() -> ArgumentsCache:
+    global __ARGUMENTS_CACHE__
+    if __ARGUMENTS_CACHE__ is None:
+        __ARGUMENTS_CACHE__ = ArgumentsCache()
+    return __ARGUMENTS_CACHE__
+
 
 def get_current_manager():
     return __DAG_CONTEXT__.get(None)
@@ -514,7 +522,7 @@ class Batch(Job):
             )
             for j in self.__jobs
         }
-        __ARGUMENTS_CACHE__.add_arguments(self.id, args)
+        get_arguments_cache().add_arguments(self.id, args)
 
     def save(self) -> Tuple[bool, str]:
         status = super().save()
@@ -523,11 +531,12 @@ class Batch(Job):
         return status
 
     def run(self) -> Tuple[bool, str]:
-        self.prepare_args()
-
         if not self.__local_run and is_dt_installed():
-            return super().run()
+            result = super().run()
+            self.prepare_args()
+            return result
         else:
+            self.prepare_args()
             os.environ["DATATAILR_BATCH_RUN_ID"] = uuid.uuid4().hex[:8]
             for step in self.__topological_sort__():
                 for job_id in step:
