@@ -35,18 +35,20 @@
 import concurrent.futures
 import subprocess
 import os
-import stat
+import sys
 import shlex
+import shutil
 import sysconfig
 from typing import Optional, Tuple
 from datatailr.logging import DatatailrLogger
 from datatailr.utils import is_dt_installed
+from datatailr import User
 
 logger = DatatailrLogger(os.path.abspath(__file__)).get_logger()
 
 if not is_dt_installed():
     logger.error("Datatailr is not installed.")
-    # sys.exit(1) # TODO: Uncomment after testing
+    sys.exit(1)
 
 
 def get_env_var(name: str, default: str | None = None) -> str:
@@ -75,30 +77,75 @@ def create_user_and_group() -> Tuple[str, str]:
     gid = get_env_var("DATATAILR_GID")
 
     # Create group if it does not exist
+    # -o: allow to create a group with a non-unique GID
     os.system(f"getent group {group} || groupadd {group} -g {gid} -o")
 
     # Create user if it does not exist
+    # -s /bin/bash: set the shell to bash
+    # -o: allow to create a user with a non-unique UID
     os.system(
-        f"getent passwd {user} || useradd -g {group} -s /bin/bash -m {user} -u {uid} -o"
+        f"getent passwd {user} || useradd -g {group} -s /bin/bash -u {uid} -o {user}"
     )
 
-    permissions = (
-        stat.S_IWOTH
-        | stat.S_IXOTH
-        | stat.S_IWUSR
-        | stat.S_IRUSR
-        | stat.S_IRGRP
-        | stat.S_IWGRP
-        | stat.S_IXUSR
-        | stat.S_IXGRP
-    )
-
-    os.makedirs(f"/home/{user}/tmp/.dt", exist_ok=True)
-    os.chmod(f"/home/{user}/tmp/.dt", permissions)
+    for directory in [
+        ".cache",
+        ".config",
+        ".config/code-server",
+        ".local",
+        "tmp",
+        "tmp/.dt",
+        ".vscode",
+    ]:
+        dir_name = f"/home/{user}/{directory}"
+        if os.path.exists(dir_name):
+            continue
+        os.makedirs(dir_name, exist_ok=True)
+        os.chown(dir_name, int(uid), int(gid))
+        os.chmod(dir_name, 0o773)  # rwxrwxr-x
 
+    copy_dotfiles(user, int(uid), int(gid))
+    create_git_config(user, int(uid), int(gid))
     return user, group
 
 
+def copy_dotfiles(user: str, uid: int, gid: int):
+    home_dir = f"/home/{user}"
+    skel_dir = "/etc/skel"
+    # Copy dotfiles from /etc/skel to the new user's home directory if they do not already exist
+    for root, dirs, files in os.walk(skel_dir):
+        rel_path = os.path.relpath(root, skel_dir)
+        target_root = os.path.join(home_dir, rel_path) if rel_path != "." else home_dir
+
+        for d in dirs:
+            target_dir = os.path.join(target_root, d)
+            if not os.path.exists(target_dir):
+                os.makedirs(target_dir, exist_ok=True)
+                os.chown(target_dir, uid, gid)
+                os.chmod(target_dir, 0o773)  # rwxrwxr-x
+
+        for f in files:
+            src_file = os.path.join(root, f)
+            target_file = os.path.join(target_root, f)
+            if not os.path.exists(target_file):
+                shutil.copy(src_file, target_file)
+                os.chown(target_file, uid, gid)
+                os.chmod(target_file, 0o773)  # rwxrwxr-x
+
+
+def create_git_config(user: str, uid: int, gid: int):
+    dt_user = User(user)
+    if not os.path.exists(f"/home/{user}/.gitconfig"):
+        with open(f"/home/{user}/.gitconfig", "w") as gitconfig_file:
+            gitconfig_file.write(
+                "[user]\n"
+                f"    name = {dt_user.first_name} {dt_user.last_name}\n"
+                f"    email = {dt_user.email}\n"
+                f"[init]\n"
+                f"    defaultBranch = main\n"
+            )
+        os.chown(f"/home/{user}/.gitconfig", int(uid), int(gid))
+
+
 def prepare_command_argv(command: str | list, user: str, env_vars: dict) -> list[str]:
     if isinstance(command, str):
         command = shlex.split(command)
@@ -201,7 +248,7 @@ def main():
             "DATATAILR_BATCH_ID": batch_id,
             "DATATAILR_BATCH_ENTRYPOINT": entrypoint,
         } | env
-        run_single_command_non_blocking("datatailr_run_batch", user, env)
+        return run_single_command_non_blocking("datatailr_run_batch", user, env)
     elif job_type == "service":
         port = get_env_var("DATATAILR_SERVICE_PORT", 8080)
         entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
@@ -209,49 +256,51 @@ def main():
             "DATATAILR_ENTRYPOINT": entrypoint,
             "DATATAILR_SERVICE_PORT": port,
         } | env
-        run_single_command_non_blocking("datatailr_run_service", user, env)
+        return run_single_command_non_blocking("datatailr_run_service", user, env)
     elif job_type == "app":
         entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         env = {
             "DATATAILR_ENTRYPOINT": entrypoint,
         } | env
-        run_single_command_non_blocking("datatailr_run_app", user, env)
+        return run_single_command_non_blocking("datatailr_run_app", user, env)
     elif job_type == "excel":
         host = get_env_var("DATATAILR_HOST", "")
-        local = get_env_var("DATATAILR_LOCAL", "")
         entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         local = get_env_var("DATATAILR_LOCAL", False)
+        dt_environment = get_env_var("DATATAILR_JOB_ENVIRONMENT")
         env = {
             "DATATAILR_ENTRYPOINT": entrypoint,
             "DATATAILR_HOST": host,
             "DATATAILR_LOCAL": local,
+            "DATATAILR_JOB_ENVIRONMENT": dt_environment,
         } | env
-        run_single_command_non_blocking("datatailr_run_excel", user, env)
+        return run_single_command_non_blocking("datatailr_run_excel", user, env)
+
     elif job_type == "workspace":
-        # Set a custom PS1 for the IDE terminal: 17:38|user@my-ide/~/dir/path:$
-        env["PS1"] = (
-            r"""\[\e[2m\]\A\[\e[0m\]|\[\e[38;5;40m\]\u\[\e[92m\]@${DATATAILR_JOB_NAME:-datatailr}\[\e[0m\]/\[\e[94;1m\]\w\[\e[0m\]\$"""
-        )
         os.makedirs("/opt/datatailr/var/log", exist_ok=True)
         ide_command = [
             "code-server",
+            "--disable-telemetry",
+            "--disable-update-check",
             "--auth=none",
-            "--bind-addr=0.0.0.0:9090",
+            "--bind-addr=127.0.0.1:9090",
             f'--app-name="Datatailr IDE {get_env_var("DATATAILR_USER")}"',
+            f"--user-data-dir=/home/{user}/.vscode",
+            f"/home/{user}",
         ]
         job_name = get_env_var("DATATAILR_JOB_NAME")
         jupyter_command = [
             "jupyter-lab",
-            "--ip='*'",
+            "--ip='127.0.0.1'",
             "--port=7070",
             "--no-browser",
             "--NotebookApp.token=''",
             "--NotebookApp.password=''",
-            f"--ServerApp.base_url=/workspace/{job_name}/jupyter/",
-            f"--ServerApp.static_url_prefix=/workspace/{job_name}/jupyter/static/",
+            f"--ServerApp.base_url=/workspace/dev/{job_name}/jupyter/",
+            f"--ServerApp.file_url_prefix=/workspace/dev/{job_name}/jupyter/static/",
             f"--ServerApp.root_dir=/home/{user}",
         ]
-        run_commands_in_parallel(
+        return run_commands_in_parallel(
             [ide_command, jupyter_command], user, env, ["code-server", "jupyter"]
         )
 
@@ -262,8 +311,9 @@ def main():
 if __name__ == "__main__":
     try:
         logger.debug("Starting job execution...")
-        main()
-        logger.debug("Job executed successfully.")
+        rc = main()
+        logger.debug(f"Job executed successfully, with code {rc}")
+        raise SystemExit(rc)
     except Exception as e:
         logger.error(f"Error during job execution: {e}")
-        raise
+        raise SystemExit(1)
