@@ -35,6 +35,8 @@ def run():
             raise ValueError("Environment variable 'DATATAILR_HOST' is not set.")
         local_flag = ""
 
-    entrypoint = f'/opt/datatailr/bin/dt-excel.sh -n -H "{hostname}" {local_flag} -p 8080 -w 8000 {entrypoint}'
+    module_name = entrypoint.split(":", 1)[0]
+
+    entrypoint = f'/opt/datatailr/bin/dt-excel.sh -n -H "{hostname}" {local_flag} -p 8080 -w 8000 {module_name}'
     logger.info(f"Running entrypoint: {entrypoint}")
     subprocess.run(entrypoint, shell=True)
