@@ -29,6 +29,8 @@ def run():
     if port is None:
         raise ValueError("Environment variable 'DATATAILR_SERVICE_PORT' is not set.")
 
-    entrypoint_module = importlib.import_module(entrypoint)
+    module_name, func_name = entrypoint.split(":")
+
+    entrypoint_module = importlib.import_module(module_name)
     logger.info(f"Running entrypoint: {entrypoint}")
-    entrypoint_module.__service_main__(int(port))
+    getattr(entrypoint_module, func_name)(int(port))
